@@ -1,6 +1,9 @@
 import logging
 import os
 
+from future.standard_library import install_aliases
+install_aliases()
+
 from tutum.api import auth
 from tutum.api.service import Service
 from tutum.api.container import Container
@@ -16,7 +19,7 @@ from tutum.api.webhookhandler import WebhookHandler
 from tutum.api.exceptions import TutumApiError, TutumAuthError
 
 
-__version__ = '0.11.0.1'
+__version__ = '0.11.0.2'
 
 # : The username used to authenticate with the API
 user = auth.load_from_file()[0] or os.environ.get('TUTUM_USER', None)
